CREATE TABLE PURCHASE_ORDER (
PURCHASE_ORDER_ID NUMBER NOT NULL,
ORDER_DATE DATE NOT NULL,
ORDER_NUMBER VARCHAR2(30 CHAR) NOT NULL,
SUPPLIER_ID NUMBER NOT NULL,
ORDER_VALUE NUMBER,
PROFIT_CENTER VARCHAR2(20 CHAR),
ORDER_COMMENT VARCHAR2(250 CHAR),
STATUS VARCHAR2(1 CHAR),
USER_CREATE VARCHAR2(20 CHAR),
DATE_CREATE DATE,
USER_CHANGE VARCHAR2(20 CHAR),
DATE_CHANGE DATE,
CONSTRAINT PK_PURCHASE_ORDER PRIMARY KEY(PURCHASE_ORDER_ID)
)
;

ALTER TABLE PURCHASE_ORDER
ADD NNLOCATION_ID NUMBER
;

CREATE SEQUENCE PURCHASE_ORDER_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE
;

CREATE TABLE PURCHASE_DETAIL (
PURCHASE_DETAIL_ID NUMBER NOT NULL,
PURCHASE_ORDER_ID NUMBER NOT NULL,
ITEM_ID NUMBER NOT NULL,
QUANTITY NUMBER NOT NULL,
QUANTITY_ORDERED NUMBER,
QUANTITY_RECEIVED NUMBER,
ITEM_UNIT VARCHAR2(10 CHAR),
NETO_PRICE NUMBER,
NETO_VALUE NUMBER,
BRUTO_VALUE NUMBER,
VAT_RATE NUMBER,
ITEM_COMMENT VARCHAR2(250 CHAR),
ITEM_CLOSED VARCHAR2(1 CHAR),
USER_CREATE VARCHAR2(20 CHAR),
DATE_CREATE DATE,
USER_CHANGE VARCHAR2(20 CHAR),
DATE_CHANGE DATE,
CONSTRAINT PK_PURCHASE_DETAIL PRIMARY KEY(PURCHASE_DETAIL_ID)
)
;

CREATE SEQUENCE PURCHASE_DETAIL_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE
;

ALTER TABLE PURCHASE_DETAIL
ADD ORDER_NR NUMBER
;

ALTER TABLE PURCHASE_DETAIL
ADD VAT_ID NUMBER
;

ALTER TABLE S_PROMET 
ADD PURCHASE_DETAIL_ID NUMBER
;

CREATE INDEX IX_S_PROMET2 ON S_PROMET (PURCHASE_DETAIL_ID)
;

CREATE OR REPLACE VIEW V_PURCHASE_ORDER AS
SELECT P.*, 
(CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (K.IME || ' ' || K.PRIIMEK) ELSE (K.PRIIMEK || ' ' || K.IME) END) AS SUPPLIER 
FROM PURCHASE_ORDER P
LEFT OUTER JOIN KUPCI K ON P.SUPPLIER_ID=K.ID
;

CREATE OR REPLACE VIEW V_PURCHASE_DETAIL AS
SELECT D.*, A.NAZIV1 AS ITEM_NAME, W.ID_DOKUMENT, W.ID_PROMET 
FROM PURCHASE_DETAIL D
LEFT OUTER JOIN S_PROMET W ON D.PURCHASE_DETAIL_ID=W.PURCHASE_DETAIL_ID
LEFT OUTER JOIN S_ARTIKLI A ON D.ITEM_ID=A.ID_ARTIKEL
;

CREATE TABLE PURCHASE_STATUS (
CODE VARCHAR2(1 CHAR) NOT NULL,
DESCRIPTION VARCHAR2(250 CHAR),
INTERNAL_DESCRIPTION VARCHAR2(250 CHAR),
ACTIVE VARCHAR2(1 CHAR),
CONSTRAINT PK_PURCHASE_STATUS PRIMARY KEY(CODE)
)
;

INSERT INTO PURCHASE_STATUS (CODE, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) VALUES ('O', 'Open', 'Open', 'Y')
;
INSERT INTO PURCHASE_STATUS (CODE, DESCRIPTION, INTERNAL_DESCRIPTION, ACTIVE) VALUES ('C', 'Closed', 'Closed', 'Y')
;

INSERT INTO PRINT_MODULI (MODULE_ID, OPIS, INTERNI_OPIS, CR_FILE) 
VALUES ('PURCHASE_ORDER', 'Purchase order', 'Purchase order', 'C-PurchaseOrder.rpt')
;

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1853, SYSDATE, '5.5', 1773, 'Purchase orders')
;
